.. highlight:: shell

============
Installation
============


Stable release (option 1)
--------------------------

To install CM4AI Generate Hierarchy, run this command in your terminal:

.. code-block:: console

    $ pip install cellmaps_generate_hierarchy

**This is the preferred method to install CM4AI Generate Hierarchy**, as it will always install the most recent stable release.

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/

It is recommended to use conda environment with python 3.8+.

From sources (option 2)
------------------------

Alternatively, CM4AI Generate Hierarchy can be installed from sources, which is particularly useful for customization
and development purposes. The sources for CM4AI Generate Hierarchy can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone https://github.com/idekerlab/cellmaps_generate_hierarchy.git

Or download the `tarball`_:

.. code-block:: console

    $ curl  -OL https://github.com/idekerlab/cellmaps_generate_hierarchy/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/idekerlab/cellmaps_generate_hierarchy
.. _tarball: https://github.com/idekerlab/cellmaps_generate_hierarchy/tarball/master
